import java.sql.*;
import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * This application reads data from a database, in this case, a MySql(www.mysql.com)
 * database, assigning titles and values to a pie series slices. 
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame  {

    PieGraph graph;

    public Main() {
	
	// Creates the chart context.
	graph=new PieGraph();
	
	// Sets chart title and title font.
	graph.setTitle(new String[]{"Monthly Sales Performance","04/2002"});
	graph.setTitleFont(new Font("SansSerif",Font.PLAIN,12));
	
	// Enables 3D chart.
	graph.set3DEnabled(true);

	// Disables legend.
	graph.setLegendEnabled(false);

	// Sets the format of values to be displayed inside slice legends.
	graph.setValueFormat("#,##0.00");

	// Sets the database driver  and connection  parameters. This  demo access  a database  named
	// 'pie' and a table named 'pietable' to fetch slices titles and values.   See the README.TXT
	// file located at this demo directory. There are  instructions  concerning  a database/table
	// creation.
	graph.setDriver("org.gjt.mm.mysql.Driver");
	graph.setConnection("jdbc:mysql://localhost:3306/pie","root","ptax7mf3");
	
	// Sets the query to fetch slices titles.
	graph.setLabelsQuery("select title from pietable");
	
	// Creates a PieSerie object and sets the query to fetch slices values.
	PieSerie ps=new PieSerie();
	ps.setValuesQuery("select value from pietable");

	// Creates an array of Color objects to set slices colors.
	Color[] color={Color.yellow,Color.red,
		       Color.green,Color.blue,
		       Color.orange,Color.magenta,
		       Color.cyan};

	// Creates seven Slice objects, setting their colors and adding them to the 
	// PieSerie object.
	for (int counter=0;counter<7;counter++) { 
	    Slice slice=new Slice();
	    slice.setColor(color[counter]);

	    // Enables slice legend.
	    SliceLegend sl=slice.getSliceLegend();
	    sl.setEnabled(true);
	    sl.setContent(SliceLegend.LABEL_AND_VALUE);

	    ps.addSlice(slice);

	}

	// Adds the PieSerie object to the cha rt context.
	graph.addSerie(ps);

        Container ct=getContentPane();
	
	ct.add("Center",graph);
	
        addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });
			  
	setSize(600,450);
	setVisible(true);
	
    }

   
    public static void main(String[] args) {
	new Main();
    }
    
}

