import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 *
 * This demo shows a date chart with an area series.
 * 
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener  {
    Graph graph;
    AreaSerie as;

    JCheckBox is3D;
    JComboBox dateIncrement;

    JScrollBar depth;
    

    public Main() {
	
	// A title for the frame
	setTitle("The JetChart Library - Date Chart Demo");
	
	double[] values={4000,4000,3000,3500,4550,5000,6000,4000,4000,3000};
	
	// Creates an area series
	as=new AreaSerie(values,"Area Series");

	// Sets area  serie properties
	setAreaSerieProperties();
	
	// Creates graphic context
	graph=new Graph();

	// Sets chart optional properties
	setChartProperties();

	// Adds the area serie to the graphic context
	graph.addSerie(as);
	
        Container ct=getContentPane();

	ct.add("Center",graph);

	// Creates a top panel to layout components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(640,500);
	

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for 3D state and date increment style changes
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==is3D) {
	    graph.set3DEnabled(is3D.isSelected());
	    depth.setEnabled(is3D.isSelected());
	}
	else if (evt.getSource()==dateIncrement) {
	    if (dateIncrement.getSelectedItem().equals("Day increment")) 
		graph.setDateIncrement(Graph.DAY_INCREMENT);
	    else if (dateIncrement.getSelectedItem().equals("Week increment"))
		graph.setDateIncrement(Graph.WEEK_INCREMENT);
	    else if (dateIncrement.getSelectedItem().equals("Month increment"))
		graph.setDateIncrement(Graph.MONTH_INCREMENT);
	    else if (dateIncrement.getSelectedItem().equals("Year increment"))
		graph.setDateIncrement(Graph.YEAR_INCREMENT);

	}

	graph.refresh();

    }

    // Event handler for chart depth adjustment
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==depth) {
	    graph.setVDepth(depth.getValue());
	    graph.repaint();
	}
    }
	    
	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
        String[] items={"Day increment","Week increment","Month increment","Year increment"};

	dateIncrement=new JComboBox(items);
	dateIncrement.addItemListener(this);
	dateIncrement.setSelectedIndex(1);

	//  Checkbox for 3D property.
	is3D=new JCheckBox("3D");
	is3D.addItemListener(this);
	
	// Scrollbar for chart depth adjustment
	depth=new JScrollBar(Scrollbar.HORIZONTAL,5,1,0,30);
        depth.setPreferredSize(new Dimension(150,depth.getPreferredSize().height));
	
	depth.setEnabled(false);
	depth.addAdjustmentListener(this);
	
	topPanel.add(is3D);
	topPanel.add(new JLabel("3D depth:"));
	topPanel.add(depth);
	topPanel.add(new JLabel("Date increment:"));
	topPanel.add(dateIncrement);
    
        Container ct=getContentPane();

	ct.add("North",topPanel);

    }

    private void setAreaSerieProperties() {
	// Sets color
	as.setColor(Color.red);
	as.setAreaLinesEnabled(false);

	// Sets values font
	as.setFont(new Font("Arial",Font.PLAIN,8));
    
    }

    private void setChartProperties() {

	graph.getToolTip().setFont(new Font("SansSerif",Font.PLAIN,10));

	// Sets start date as July 01, 2000
	graph.setStartDate("07012000");

	// Sets date labels in a week by week increment. Day by day increment is the default one.
	graph.setDateIncrement(Graph.WEEK_INCREMENT);
	graph.setLabelsAxisStartGap(0);

	// Sets a text to prefix the tooltip content
	graph.getToolTip().setLabel("Label and value: ");

	// Sets the tooltip content type as label and value.
	graph.getToolTip().setType(ToolTip.LABEL_AND_VALUE);
	
	// Enables tooltip
        graph.getToolTip().setEnabled(true);

	// Sets chart title
	String[] title={"The JetChart Library - a date chart demo","displaying  one area series."};
	graph.setTitle(title);
	
	// Sets labels title
	graph.getBottomTitle().setText("Labels Title");

	// Sets values title
	graph.getLeftTitle().setText("Values Title");

	// Applies gradient colors to graphic context
	graph.setGradientColors(Color.yellow,new Color(51,102,255));
	//graph.setGradientOrientation(graph.LEFT_TO_RIGHT);

	// Enables chart and legend dragging. A double-click over chart alternates
	// between moving chart and scale adjustment.
	graph.setDraggingEnabled(true);

	// Enables grid and sets grid color
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(Color.gray.darker());

	// Sets legend orientation,horizontal and vertical gaps,opacity  and position. Legend can be dinamically
	// dragged, if the Graph draggable property is set to true.
	graph.getLegend().setOrientation(Legend.HORIZONTAL);


	graph.setValueFormat("###,##0.00");
    
	// Sets depth for vertical charts
	graph.setVDepth(5);

    }

    public static void main(String[] args) {
	new Main();
    }
}
